Function frame::runtime::apis::check_equivocation_proof
pub fn check_equivocation_proof<H, N>(report: EquivocationProof<H, N>) -> boolwhere
H: Clone + Encode + PartialEq<H>,
N: Clone + Encode + PartialEq<N>,Expand description
Verifies the equivocation proof by making sure that both votes target different blocks and that its signatures are valid.