pub fn check_message_signature<H, N>(
    message: &Message<H, N>,
    id: &Public,
    signature: &Signature,
    round: u64,
    set_id: u64
) -> boolwhere
    H: Encode,
    N: Encode,
Check a message signature by encoding the message as a localized payload and verifying the provided signature using the expected authority id.