Struct frame::runtime::apis::Extensions
pub struct Extensions { /* private fields */ }Expand description
Stores extensions that should be made available through the externalities.
Implementations
impl Extensions
impl Extensions
pub fn new() -> Extensions
pub fn new() -> Extensions
Create new instance of Self.
pub fn register_with_type_id(
&mut self,
type_id: TypeId,
extension: Box<dyn Extension, Global>
) -> Result<(), Error>
pub fn register_with_type_id( &mut self, type_id: TypeId, extension: Box<dyn Extension, Global> ) -> Result<(), Error>
Register extension extension using the given type_id.
pub fn get_mut(
&mut self,
ext_type_id: TypeId
) -> Option<&mut (dyn Any + 'static)>
pub fn get_mut( &mut self, ext_type_id: TypeId ) -> Option<&mut (dyn Any + 'static)>
Return a mutable reference to the requested extension.
pub fn deregister(&mut self, type_id: TypeId) -> bool
pub fn deregister(&mut self, type_id: TypeId) -> bool
Deregister extension for the given type_id.
Returns true when the extension was registered.
pub fn iter_mut(
&mut self
) -> impl Iterator<Item = (&TypeId, &mut Box<dyn Extension, Global>)>
pub fn iter_mut( &mut self ) -> impl Iterator<Item = (&TypeId, &mut Box<dyn Extension, Global>)>
Returns a mutable iterator over all extensions.
pub fn merge(&mut self, other: Extensions)
pub fn merge(&mut self, other: Extensions)
Merge other into self.
If both contain the same extension, the extension instance of other will overwrite the
instance found in self.