Struct frame::runtime::apis::GrandpaJustification
pub struct GrandpaJustification<Header>where
Header: Header,{
pub round: u64,
pub commit: Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>,
pub votes_ancestries: Vec<Header, Global>,
}Expand description
A GRANDPA justification for block finality, it includes a commit message and an ancestry proof including all headers routing all precommit target blocks to the commit target block. Due to the current voting strategy the precommit targets should be the same as the commit target, since honest voters don’t vote past authority set change blocks.
This is meant to be stored in the db and passed around the network to other nodes, and are used by syncing nodes to prove authority set handoffs.
Fields
round: u64commit: Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>votes_ancestries: Vec<Header, Global>Trait Implementations
impl<Header> Clone for GrandpaJustification<Header>where
Header: Clone + Header,
impl<Header> Clone for GrandpaJustification<Header>where Header: Clone + Header,
fn clone(&self) -> GrandpaJustification<Header>
fn clone(&self) -> GrandpaJustification<Header>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<Header> Debug for GrandpaJustification<Header>where
Header: Debug + Header,
impl<Header> Debug for GrandpaJustification<Header>where Header: Debug + Header,
impl<Header> Decode for GrandpaJustification<Header>where
Header: Header,
Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: Decode,
Vec<Header, Global>: Decode,
impl<Header> Decode for GrandpaJustification<Header>where Header: Header, Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: Decode, Vec<Header, Global>: Decode,
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy
) -> Result<GrandpaJustification<Header>, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>( __codec_input_edqy: &mut __CodecInputEdqy ) -> Result<GrandpaJustification<Header>, Error>where __CodecInputEdqy: Input,
Attempt to deserialise the value from input.
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>( input: &mut I, dst: &mut MaybeUninit<Self> ) -> Result<DecodeFinished, Error>where I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where I: Input,
Attempt to skip the encoded value from input. Read more
fn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
Returns the fixed encoded size of the type. Read more
impl<Header> Encode for GrandpaJustification<Header>where
Header: Header,
Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: Encode,
Vec<Header, Global>: Encode,
impl<Header> Encode for GrandpaJustification<Header>where Header: Header, Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: Encode, Vec<Header, Global>: Encode,
fn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy
)where
__CodecOutputEdqy: Output + ?Sized,
fn encode_to<__CodecOutputEdqy>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy )where __CodecOutputEdqy: Output + ?Sized,
Convert self to a slice and append it to the destination.
fn using_encoded<R, F>(&self, f: F) -> Rwhere
F: FnOnce(&[u8]) -> R,
fn using_encoded<R, F>(&self, f: F) -> Rwhere F: FnOnce(&[u8]) -> R,
Convert self to a slice and then invoke the given closure with it.
fn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl<Header> PartialEq<GrandpaJustification<Header>> for GrandpaJustification<Header>where
Header: PartialEq<Header> + Header,
impl<Header> PartialEq<GrandpaJustification<Header>> for GrandpaJustification<Header>where Header: PartialEq<Header> + Header,
fn eq(&self, other: &GrandpaJustification<Header>) -> bool
fn eq(&self, other: &GrandpaJustification<Header>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<Header> TypeInfo for GrandpaJustification<Header>where
Header: Header + TypeInfo + 'static,
Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: TypeInfo + 'static,
Vec<Header, Global>: TypeInfo + 'static,
impl<Header> TypeInfo for GrandpaJustification<Header>where Header: Header + TypeInfo + 'static, Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: TypeInfo + 'static, Vec<Header, Global>: TypeInfo + 'static,
impl<Header> EncodeLike<GrandpaJustification<Header>> for GrandpaJustification<Header>where Header: Header, Commit<<Header as Header>::Hash, <Header as Header>::Number, Signature, Public>: Encode, Vec<Header, Global>: Encode,
impl<Header> Eq for GrandpaJustification<Header>where Header: Eq + Header,
impl<Header> StructuralEq for GrandpaJustification<Header>where Header: Header,
impl<Header> StructuralPartialEq for GrandpaJustification<Header>where Header: Header,