pub struct InherentData { /* private fields */ }
Inherent data to include in a block.

Implementations



impl InherentData

pub fn new() -> InherentData

Create a new instance.

pub fn put_data<I>( &mut self, identifier: [u8; 8], inherent: &I ) -> Result<(), Error>where I: Encode,

Put data for an inherent into the internal storage.

Return

Returns Ok(()) if the data could be inserted and no data for an inherent with the same identifier existed, otherwise an error is returned.

Inherent identifiers need to be unique, otherwise decoding of these values will not work!

pub fn replace_data<I>(&mut self, identifier: [u8; 8], inherent: &I)where I: Encode,

Replace the data for an inherent.

If it does not exist, the data is just inserted.

pub fn get_data<I>(&self, identifier: &[u8; 8]) -> Result<Option<I>, Error>where I: Decode,

Returns the data for the requested inherent.

Return
  • Ok(Some(I)) if the data could be found and deserialized.
  • Ok(None) if the data could not be found.
  • Err(_) if the data could be found, but deserialization did not work.

pub fn len(&self) -> usize

Get the number of inherents in this instance