Struct frame::runtime::apis::TrieBackend
pub struct TrieBackend<S, H, C = LocalTrieCache<H>>where
S: TrieBackendStorage<H>,
H: Hasher,{ /* private fields */ }Expand description
Patricia trie-based backend. Transaction type is an overlay of changes to commit.
Implementations
impl<H> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>where
H: Hasher,
<H as Hasher>::Out: Codec + Ord,
impl<H> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>where H: Hasher, <H as Hasher>::Out: Codec + Ord,
pub fn update<T>(
&self,
changes: T,
state_version: StateVersion
) -> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>where
T: IntoIterator<Item = (Option<ChildInfo>, Vec<(Vec<u8, Global>, Option<Vec<u8, Global>>), Global>)>,
pub fn update<T>( &self, changes: T, state_version: StateVersion ) -> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>where T: IntoIterator<Item = (Option<ChildInfo>, Vec<(Vec<u8, Global>, Option<Vec<u8, Global>>), Global>)>,
Copy the state, with applied updates
pub fn insert<T>(&mut self, changes: T, state_version: StateVersion)where
T: IntoIterator<Item = (Option<ChildInfo>, Vec<(Vec<u8, Global>, Option<Vec<u8, Global>>), Global>)>,
pub fn insert<T>(&mut self, changes: T, state_version: StateVersion)where T: IntoIterator<Item = (Option<ChildInfo>, Vec<(Vec<u8, Global>, Option<Vec<u8, Global>>), Global>)>,
Insert values into backend trie.
pub fn update_backend(
&self,
root: <H as Hasher>::Out,
changes: MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>
) -> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>
pub fn update_backend( &self, root: <H as Hasher>::Out, changes: MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>> ) -> TrieBackend<MemoryDB<H, PrefixedKey<H>, Vec<u8, Global>>, H, LocalTrieCache<H>>
Merge trie nodes into this backend.
impl<S, H, C> TrieBackend<S, H, C>where
S: TrieBackendStorage<H>,
H: Hasher,
C: TrieCacheProvider<H> + Send + Sync,
<H as Hasher>::Out: Codec,
impl<S, H, C> TrieBackend<S, H, C>where S: TrieBackendStorage<H>, H: Hasher, C: TrieCacheProvider<H> + Send + Sync, <H as Hasher>::Out: Codec,
pub fn essence(&self) -> &TrieBackendEssence<S, H, C>
pub fn essence(&self) -> &TrieBackendEssence<S, H, C>
Get backend essence reference.
pub fn backend_storage_mut(&mut self) -> &mut S
pub fn backend_storage_mut(&mut self) -> &mut S
Get backend storage reference.
pub fn backend_storage(&self) -> &S
pub fn backend_storage(&self) -> &S
Get backend storage reference.
pub fn into_storage(self) -> S
pub fn into_storage(self) -> S
Consumes self and returns underlying storage.
pub fn extract_proof(self) -> Option<StorageProof>
pub fn extract_proof(self) -> Option<StorageProof>
Extract the StorageProof.
This only returns Some when there was a recorder set.