Type Definition frame::runtime::apis::AuthorityPair
pub type AuthorityPair = Pair;Expand description
The grandpa crypto scheme defined via the keypair type.
pub type AuthorityPair = Pair;The grandpa crypto scheme defined via the keypair type.